Tooling
=======

Prettypretty includes a command line tool for visualizing terminal colors.

.. autoprogram:: prettypretty.color.grid:create_parser()
    :prog: python -m prettypretty.color.grid
    :groups:
